Trait ToSocketAddrs

pub trait ToSocketAddrs {
    type Iter: Iterator<Item = SocketAddr>;

    // Required method
    fn to_socket_addrs(&self) -> Result<Self::Iter>;
}
A trait for objects which can be converted or resolved to one or more SocketAddr values.

This trait is used for generic address resolution when constructing network objects. By default it is implemented for the following types:

Required Associated Types

type Iter: Iterator<Item = SocketAddr>

Returned iterator over socket addresses which this type may correspond to.

Required Methods

fn to_socket_addrs(&self) -> Result<Self::Iter>

Converts this object to an iterator of resolved SocketAddrs.

Implementations on Foreign Types

Source

impl ToSocketAddrs for (&str, u16)

Available on crate feature net only.
Source

impl ToSocketAddrs for (IpAddr, u16)

Source

impl ToSocketAddrs for (String, u16)

Available on crate feature net only.
Source

impl ToSocketAddrs for (Ipv4Addr, u16)

Source

impl ToSocketAddrs for str

Available on crate feature net only.
Source

impl ToSocketAddrs for String

Available on crate feature net only.
Source

impl<'a> ToSocketAddrs for &'a [SocketAddr]

Source

impl<T: ToSocketAddrs + ?Sized> ToSocketAddrs for &T

Implementors